package com.aucma.dms.controller;

import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.core.page.TableDataInfo;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.dms.domain.DmsBaseMaintStation;
import com.aucma.dms.service.IDmsBaseMaintStationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;




/**
 * 保养部位信息Controller
 * 
 * @author xins
 * @date 2024-01-05
 */
@RestController
@RequestMapping("/dms/station")
public class DmsBaseMaintStationController extends BaseController
{
    @Autowired
    private IDmsBaseMaintStationService dmsBaseMaintStationService;

    /**
     * 查询保养部位信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:station:list')" )
    @GetMapping("/list")
    public TableDataInfo list(DmsBaseMaintStation dmsBaseMaintStation)
    {
        startPage();
        List<DmsBaseMaintStation> list = dmsBaseMaintStationService.selectDmsBaseMaintStationList(dmsBaseMaintStation);
        return getDataTable(list);
    }

    /**
     * 导出保养部位信息列表
     */
    //@PreAuthorize("@ss.hasPermi('dms:station:export')" )
    ////@Log(title = "保养部位信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, DmsBaseMaintStation dmsBaseMaintStation)
    {
        List<DmsBaseMaintStation> list = dmsBaseMaintStationService.selectDmsBaseMaintStationList(dmsBaseMaintStation);
        ExcelUtil<DmsBaseMaintStation> util = new ExcelUtil<DmsBaseMaintStation>(DmsBaseMaintStation.class);
        util.exportExcel(response, list, "保养部位信息数据");
    }

    /**
     * 获取保养部位信息详细信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:station:query')" )
    @GetMapping(value = "/{maintStationId}")
    public AjaxResult getInfo(@PathVariable("maintStationId") Long maintStationId)
    {
        return success(dmsBaseMaintStationService.selectDmsBaseMaintStationByMaintStationId(maintStationId));
    }

    /**
     * 新增保养部位信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:station:add')" )
    ////@Log(title = "保养部位信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody DmsBaseMaintStation dmsBaseMaintStation)
    {
        return toAjax(dmsBaseMaintStationService.insertDmsBaseMaintStation(dmsBaseMaintStation));
    }

    /**
     * 修改保养部位信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:station:edit')" )
    ////@Log(title = "保养部位信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody DmsBaseMaintStation dmsBaseMaintStation)
    {
        return toAjax(dmsBaseMaintStationService.updateDmsBaseMaintStation(dmsBaseMaintStation));
    }

    /**
     * 删除保养部位信息
     */
    //@PreAuthorize("@ss.hasPermi('dms:station:remove')" )
    ////@Log(title = "保养部位信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{maintStationIds}")
    public AjaxResult remove(@PathVariable Long[] maintStationIds)
    {
        return toAjax(dmsBaseMaintStationService.deleteDmsBaseMaintStationByMaintStationIds(maintStationIds));
    }
}
